---
name: Bug report
about: Create a report to help us improve

---

**Describe the bug**
- What did you do?
- What happened?
- What was expected?

**Which version of lucivy are you using?**
If "master",  ideally give the specific sha1 revision.

**To Reproduce**

If your bug is deterministic, can you give a minimal reproducing code?
Some bugs are not deterministic. Can you describe with precision in which context it happened?
If this is possible, can you share your code?
